#ifndef TIPOS_H
#define TIPOS_H

#include "mp3player.h"
#include <pspsdk.h>
#include <pspkernel.h>
#include <pspdisplay.h>
#include <psputility.h>
#include <pspctrl.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <stdarg.h>
#include <psptypes.h>
#include <pspdebug.h>
#include <dirent.h>
#include <pspiofilemgr.h>
#include <pspiofilemgr_dirent.h>
#include <pspgu.h>
#include <png.h>

#include "graphics.h"
#include "framebuffer.h"


// Lista de defines usados
	
#define		printf			pspDebugScreenPrintf		// Define printf para ser usado con sencillez
#define		color1			0x444444			// Color principal para las letras
#define		color2			0XDEDEDE			// Color para opciones seleccionadas
#define		color3			0X67fF90			// Color para titulos o letras resaltadas
#define		color4			0XA0FFCF			// Color para letras secundarias
#define		delay			100000				// Tiempo de delay para evitar el rebote de pulsaciones
#define		delay_corto		5000				// Tiempo de delay para refrescar el puntero creado por la funcion 'juego'
#define		delay_creditos		3000000				// Tiempo de delay entre creditos
#define		MAX_RESPUESTA		30
#define		MAX_PREGUNTA		100
#define		MAX_CADENA		256
#define		MAX_FILENAME		256
#define		CHECK_ID		12349				// Debe ser un numero entero que lo describa
#define		MAX_NOMBRE		11				// Define la longitud maxima para el nombre de jugador
#define		MAX_FILE		128
#define		SAVE_FILE		"savegame.tpsp"			// Nombre que se utilizara para leer y escribir el savegame
#define		CHECK_ID		12349				// Check ID para comprobar las librerias de preguntas
#define		VERSION			0.1				// Version para comprobar el archivo de savegame
#define		clear			pspDebugScreenClear
#define		MAX_PREGUNTAS		1024				// Maximo numero de preguntas que puede contener la libreria


// Colores para la ventana de dialogo con opciones

#define		color_banda_up		0x234567					
#define		color_fondo		0x662255
#define		color_titulo		0x8899BB
#define		color_opciones		0x3478BA
#define		color_cursor		0x4400FF


// Definicion de tipos personalizados

typedef char	TCategoria[MAX_CADENA];					// Cadena que es usada para el tipo TCabecera

typedef char	TNombre[128];						// Almacena la lista de archivos que hay en un directorio o cualquier uso parecido
typedef struct {							// Hasta un maximo de seis archivos
	TNombre	archivo[6];
	int		numero;
	}TLista;

typedef struct nodo{
	int		categoria;
	char	pregunta	[MAX_PREGUNTA];
	char	respuesta1	[MAX_RESPUESTA];
	char	respuesta2	[MAX_RESPUESTA];
	char	respuesta3	[MAX_RESPUESTA];
	char	respuesta4	[MAX_RESPUESTA];
	int		correcta;
	struct	nodo		*siguiente;
}TPregunta;

typedef struct {							// El archivo-libreria de trivial contiene un bloque de
	int		preguntas_totales;				// tipo TCabecera, y despues todos los de preguntas 
	int		categorias_totales;
	int		check_id;
	TCategoria	categorias[10];
	TPregunta	*actual;					// Para saber cuantos se tienen que leer, se tiene el valor guardado en el bloque previo
}TCabecera;

typedef struct {							// Cabecera del archivo savegame
	int		perfiles_totales;
	float		version;
}TCabecera_savegame;

typedef struct {							// Contiene todos los datos asociados a un jugador
	char		nombre[MAX_NOMBRE], libreria[MAX_FILENAME];
	int		puntuacion, aciertos, fallos, victorias, color;
	int		respondidas[MAX_PREGUNTAS];			// Debe ser mayor o igual al maximo numero de preguntas que tenga la libreria
}TJugador;								// es booleano, las preguntas que ya se hayan respondido corresponden a 1 y el resto a 0
									// Explicacion: se utiliza para no repetir en una misma partida dos veces la misma
									// pregunta a un mismo jugador. Por lo que debe haber una lista por cada jugador.
									// Debe inicializarse a cero al comenzar la partida.

typedef struct {							// Contiene todos los datos de una partida, incluidos los jugadores y las opciones
	int 		num_jugadores, tiempo_pregunta, tiradas;
	TJugador	jugador[7];
}TPartida;

#endif

